Module token_parser

Module token_parser 

Token-based parser for JCL

This module implements a recursive descent parser that consumes tokens from the lexer to build an AST. This approach correctly handles keyword/identifier distinction.

Structs

TokenParser
Parser that consumes tokens to produce an AST

Functions

parse
Parse source code using the token-based parser