Token-based parser for JCL
This module implements a recursive descent parser that consumes tokens from the lexer to build an AST. This approach correctly handles keyword/identifier distinction.
Structs
- Token
Parser - Parser that consumes tokens to produce an AST
Functions
- parse
- Parse source code using the token-based parser